@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 
-__version__   = '2.3.2'
+__version__   = '2.4.8'
 __author__    = "Avinash Kak (kak@purdue.edu)"
-__date__      = '2023-September-25'                   
-__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.3.2.html'
-__copyright__ = "(C) 2023 Avinash Kak. Python Software Foundation."
+__date__      = '2024-April-27'                   
+__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.4.8.html'
+__copyright__ = "(C) 2024 Avinash Kak. Python Software Foundation."
 
 
 __doc__ = '''
@@ -468,7 +468,6 @@ class AdversarialLearning(object):
         def show_sample_images_from_dataset(self, dlstudio):
             data = next(iter(self.train_dataloader))    
             real_batch = data[0]
-            first_im = real_batch[0]
             self.dlstudio.display_tensor_as_image(torchvision.utils.make_grid(real_batch, padding=2, pad_value=1, normalize=True))
 
         def set_dataloader(self):
@@ -996,9 +995,8 @@ class AdversarialLearning(object):
                     ##  update the netD weights.
                     output = netD(fakes.detach()).view(-1)    
                     lossD_for_fakes = criterion(output, label)    
-                    ##  At this point, we do not care if the following call also calculates the gradients
-                    ##  wrt the Discriminator weights since we are going to next iteration with 'netD.zero_grad()':
                     lossD_for_fakes.backward()          
+                    ##  The following is just for displaying the losses:
                     lossD = lossD_for_reals + lossD_for_fakes    
                     d_losses_per_print_cycle.append(lossD)  
                     ##  Only the Discriminator weights are incremented:
@@ -1006,13 +1004,17 @@ class AdversarialLearning(object):
 
                     ##  Minimization Part of the Min-Max Objective of Eq. (3):
                     ##
-                    ##  That brings to the min part of the max-min optimization described in Eq. (3) the doc 
+                    ##  That brings us to the min part of the max-min optimization described in Eq. (3) the doc 
                     ##  section at the beginning of this file.  The min part requires that we minimize 
                     ##  "1 - D(G(z))" which, since D is constrained to lie in the interval (0,1), requires that 
                     ##  we maximize D(G(z)).  We accomplish that by applying the Discriminator to the output 
                     ##  of the Generator and use 1 as the target for each image:
                     netG.zero_grad()   
                     label.fill_(real_label)  
+                    ##  The following forward prop will compute the partials wrt the discriminator params also, but
+                    ##  they will never get used for updating param vals for two reasons: (1) We call "step()" on 
+                    ##  just optimizerG as shown later below; and (2) We call "netD.zero_grad()" at the beginning of 
+                    ##  each training cycle.
                     output = netD(fakes).view(-1)   
                     lossG = criterion(output, label)          
                     g_losses_per_print_cycle.append(lossG) 
@@ -1149,7 +1151,8 @@ class AdversarialLearning(object):
                         #  Critic network to just the training images, with each image subject to a "gradient
                         #  target" of "-1".
                         netC.zero_grad()                                                                            
-                        real_images_in_batch =  data_iter.next()
+#                        real_images_in_batch =  data_iter.next()
+                        real_images_in_batch =  next(data_iter)
                         i += 1
                         real_images_in_batch =  real_images_in_batch[0].to(self.device)   
                         #  Need to know how many images we pulled in since at the tailend of the dataset, the 
@@ -1307,7 +1310,8 @@ class AdversarialLearning(object):
                         #  a regular WGAN.  We want to train the Critic to recognize the training images and,
                         #  at the same time, the Critic should try to not believe the output of the Generator.
                         netC.zero_grad()                                                                            
-                        real_images_in_batch =  data_iter.next()
+#                        real_images_in_batch =  data_iter.next()
+                        real_images_in_batch =  next(data_iter)
                         i += 1
                         real_images_in_batch =  real_images_in_batch[0].to(self.device)   
                         #  Need to know how many images we pulled in since at the tailend of the dataset, the 
