@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 
-__version__   = '2.3.2'
+__version__   = '2.4.8'
 __author__    = "Avinash Kak (kak@purdue.edu)"
-__date__      = '2023-September-25'                   
-__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.3.2.html'
-__copyright__ = "(C) 2023 Avinash Kak. Python Software Foundation."
+__date__      = '2024-April-27'                   
+__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.4.8.html'
+__copyright__ = "(C) 2024 Avinash Kak. Python Software Foundation."
 
 
 __doc__ = '''
