@@ -44,8 +44,8 @@ os.environ['PYTHONHASHSEED'] = str(seed)
 from DLStudio import *
 
 dls = DLStudio(
-#                  dataroot = "/home/kak/ImageDatasets/PurdueShapes5/",
-                  dataroot = "./data/PurdueShapes5/",
+                  dataroot = "/home/kak/ImageDatasets/PurdueShapes5/",
+#                  dataroot = "./data/PurdueShapes5/",
                   image_size = [32,32],
                   path_saved_model = "./saved_model",
                   momentum = 0.9,
@@ -53,7 +53,7 @@ dls = DLStudio(
                   epochs = 2,
                   batch_size = 4,
                   classes = ('rectangle','triangle','disk','oval','star'),
-#                  use_gpu = True,
+                  use_gpu = True,
               )
 
 
@@ -83,7 +83,7 @@ num_layers = len(list(model.parameters()))
 print("\nThe number of layers in the model: %d\n\n" % num_layers)
 
 
-detector.run_code_for_training_with_CrossEntropy_and_MSE_Losses(model)
+detector.run_code_for_training_with_CrossEntropy_and_MSE_Losses(model, show_images=True)
 
 import pymsgbox
 response = pymsgbox.confirm("Finished training.  Start testing on unseen data?")
