@@ -4,8 +4,8 @@
 
 """
 This script should be your starting point if you wish to learn how to use the
-mUnet neural network for semantic segmentation of images.  As mentioned elsewhere in
-the main documentation page, mUnet assigns an output channel to each different type of
+mUNet neural network for semantic segmentation of images.  As mentioned elsewhere in
+the main documentation page, mUNet assigns an output channel to each different type of
 object that you wish to segment out from an image. So, given a test image at the
 input to the network, all you have to do is to examine each channel at the output for
 segmenting out the objects that correspond to that output channel.
@@ -46,16 +46,21 @@ dls = DLStudio(
                   use_gpu = True,
               )
 
-segmenter = DLStudio.SemanticSegmentation( dl_studio = dls )
+segmenter = DLStudio.SemanticSegmentation( 
+                  dl_studio = dls, 
+                  max_num_objects = 5,
+              )
 
 dataserver_train = DLStudio.SemanticSegmentation.PurdueShapes5MultiObjectDataset(
                           train_or_test = 'train',
                           dl_studio = dls,
+                          segmenter = segmenter,
                           dataset_file = "PurdueShapes5MultiObject-10000-train.gz", 
                         )
 dataserver_test = DLStudio.SemanticSegmentation.PurdueShapes5MultiObjectDataset(
                           train_or_test = 'test',
                           dl_studio = dls,
+                          segmenter = segmenter,
                           dataset_file = "PurdueShapes5MultiObject-1000-test.gz"
                         )
 segmenter.dataserver_train = dataserver_train
@@ -63,8 +68,8 @@ segmenter.dataserver_test = dataserver_test
 
 segmenter.load_PurdueShapes5MultiObject_dataset(dataserver_train, dataserver_test)
 
-model = segmenter.mUnet(skip_connections=True, depth=16)
-#model = segmenter.mUnet(skip_connections=False, depth=4)
+model = segmenter.mUNet(skip_connections=True, depth=16)
+#model = segmenter.mUNet(skip_connections=False, depth=4)
 
 number_of_learnable_params = sum(p.numel() for p in model.parameters() if p.requires_grad)
 print("\n\nThe number of learnable parameters in the model: %d\n" % number_of_learnable_params)
