@@ -54,12 +54,12 @@ data_archive =  "en_es_xformer_8_90000.tar.gz"
 
 max_seq_length = 10
 
-embedding_size = 256                 ## for running in RVL Cloud
+embedding_size = 256        
 #embedding_size = 128
-#embedding_size = 64                   ## for running on laptop
+#embedding_size = 64        
 
-num_basic_encoders = num_basic_decoders = num_atten_heads = 4     ## for running on RVL Cloud
-#num_basic_encoders = num_basic_decoders = num_atten_heads = 2      ## for running on laptop
+num_basic_encoders = num_basic_decoders = num_atten_heads = 4     
+#num_basic_encoders = num_basic_decoders = num_atten_heads = 2    
 
 #optimizer_params = {'beta1' : 0.9,  'beta2': 0.98,  'epsilon' : 1e-9}
 optimizer_params = {'beta1' : 0.9,  'beta2': 0.98,  'epsilon' : 1e-6}
@@ -71,11 +71,14 @@ masking = False
 
 dls = DLStudio(
                 dataroot = dataroot,
-                path_saved_model = {"encoder" : "./saved_encoder", "decoder" : "./saved_decoder"},
+                path_saved_model = {"encoder" : "./saved_encoder", 
+                                    "decoder" : "./saved_decoder", 
+                                    "embeddings_generator_en" : "./saved_embeddings_generator_en",
+                                    "embeddings_generator_es" : "./saved_embeddings_generator_es",
+                                   },
                 batch_size = 50,
                 use_gpu = True,
                 epochs = 40,
-#                epochs = 2,
               )
 
 xformer = TransformerFG( 
@@ -123,8 +126,8 @@ else:
     xformer.run_code_for_training_TransformerFG(dls,master_encoder,master_decoder,display_train_loss=True,
                                                                                         checkpoints_dir="checkpoints_no_masking_FG")
 
-import pymsgbox
-response = pymsgbox.confirm("Finished training.  Start evaluation?")
+#import pymsgbox
+#response = pymsgbox.confirm("Finished training.  Start evaluation?")
 
-if response == "OK": 
-    xformer.run_code_for_evaluating_TransformerFG(master_encoder, master_decoder, 'myoutput.txt')
+#if response == "OK": 
+xformer.run_code_for_evaluating_TransformerFG(master_encoder, master_decoder, 'myoutput.txt')
