@@ -45,6 +45,7 @@ os.environ['PYTHONHASHSEED'] = str(seed)
 from DLStudio import *
 from Transformers import *
 
+
 dataroot = "./data/"
 #dataroot = "/home/kak/TextDatasets/en_es_corpus_xformer/"
 #dataroot = "/mnt/cloudNAS3/Avi/TextDatasets/en_es_corpus_xformer/"
@@ -54,24 +55,27 @@ data_archive =  "en_es_xformer_8_90000.tar.gz"
 
 max_seq_length = 10
 
-embedding_size = 256                       ##  for running on RVL Cloud
+embedding_size = 256               
 #embedding_size = 128
-#embedding_size = 64                         ##  for running on laptop
+#embedding_size = 64               
 
-num_basic_encoders = num_basic_decoders = num_atten_heads = 4       ##  for running on RVL Cloud
-#num_basic_encoders = num_basic_decoders = num_atten_heads = 2        ##  for running on laptop
+num_basic_encoders = num_basic_decoders = num_atten_heads = 4   
+#num_basic_encoders = num_basic_decoders = num_atten_heads = 2  
 
 masking = True
 #masking = False
 
 dls = DLStudio(
                 dataroot = dataroot,
-                path_saved_model = {"encoder" : "./saved_encoder", "decoder" : "./saved_decoder"},
+                path_saved_model = {"encoder" : "./saved_encoder", 
+                                    "decoder" : "./saved_decoder", 
+                                    "embeddings_generator_en" : "./saved_embeddings_generator_en",
+                                    "embeddings_generator_es" : "./saved_embeddings_generator_es",
+                                   },
                 learning_rate =  1e-5, 
                 batch_size = 50,
                 use_gpu = True,
                 epochs = 60,
-#                epochs = 2,
       )
 
 xformer = TransformerPreLN( 
@@ -117,10 +121,9 @@ else:
     xformer.run_code_for_training_TransformerPreLN(dls,master_encoder,master_decoder,display_train_loss=True,
                                                                         checkpoints_dir="checkpoints_no_masking_PreLN")
 
-import pymsgbox
+#import pymsgbox
+#response = pymsgbox.confirm("Finished training.  Start evaluation?")
+#if response == "OK": 
 
-response = pymsgbox.confirm("Finished training.  Start evaluation?")
-
-if response == "OK": 
-    xformer.run_code_for_evaluating_TransformerPreLN(master_encoder, master_decoder)
+xformer.run_code_for_evaluating_TransformerPreLN(master_encoder, master_decoder)
 
