@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 
-__version__   = '2.3.2'
+__version__   = '2.4.8'
 __author__    = "Avinash Kak (kak@purdue.edu)"
-__date__      = '2023-September-25'                   
-__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.3.2.html'
-__copyright__ = "(C) 2023 Avinash Kak. Python Software Foundation."
+__date__      = '2024-April-27'                   
+__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.4.8.html'
+__copyright__ = "(C) 2024 Avinash Kak. Python Software Foundation."
 
 
 __doc__ = '''
@@ -617,7 +617,7 @@ class MetricLearning(object):
             test_embeddings = np.concatenate( (test_embeddings, embeddings.detach().cpu().numpy()), axis=0)
             test_labels = np.concatenate( (test_labels, labels), axis=0 )
         index = faiss.IndexFlatL2(self.embedDim)                                ## create the indexer
-        print(index.is_trained)
+#        print(index.is_trained)
         index.add(train_embeddings)
         ##  We want to see 3 nearest neighbors.  Ordinarily, if you are only calculated "Precision @ rank 1",
         ##  you'll only need to set "k = 1".  
