@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 
-__version__   = '2.3.2'
+__version__   = '2.4.8'
 __author__    = "Avinash Kak (kak@purdue.edu)"
-__date__      = '2023-September-25'                   
-__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.3.2.html'
-__copyright__ = "(C) 2023 Avinash Kak. Python Software Foundation."
+__date__      = '2024-April-27'                   
+__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.4.8.html'
+__copyright__ = "(C) 2024 Avinash Kak. Python Software Foundation."
 
 
 __doc__ = '''
@@ -910,7 +910,8 @@ class Seq2SeqLearning(object):
                         list_of_embeddings.append(np.array(embedding))
                 list_of_embeddings.insert(0,self.sos_tensor_en.numpy())  
                 list_of_embeddings.append(self.eos_tensor_en.numpy()) 
-                sentence_tensor = torch.FloatTensor( list_of_embeddings )
+#                sentence_tensor = torch.FloatTensor( list_of_embeddings )
+                sentence_tensor = torch.FloatTensor( np.array(list_of_embeddings) )
             elif lang == "es":
                 sentence_tensor = torch.zeros(len(words), 1, dtype=torch.long)
                 for i,word in enumerate(words):
